@@ -1,7 +1,7 @@
-"""fmdpy"""
-import base64
+"""fmdpy."""
+from . import conf
 
-VERSION = "0.3"
+VERSION = "0.5"
 install_requires = ['ffmpeg-python', 'click', 'music-tag>=0.4.3', 'requests',
                     'pillow', 'lyricsgenius', 'dataclasses', 'spotipy']
 
@@ -16,4 +16,4 @@ ART = r'''  _| |_ |  \ /  |   /\  (   _   ) || || |
  \_   _/| |   | |/ /__\ \| | | |   | |
    |_|  |_|   |_/________\_| |_|   |_|
                                          '''
-mnc = base64.decodebytes
+config = conf.load()
